/* Beispiele aus dem Buch "LDAP fuer Java-Entwickler", 
 * Stefan Zoerner, 4. aktualisierte Auflage 2013
 *  
 * Webseite zum Buch: http://www.ldapjava.de/ 
 * Software & Support Media GmbH / entwickler.press, http://www.entwickler-press.de/
 */
package ldapbuch.kapitel3.explizit;

import netscape.ldap.LDAPConnection;
import netscape.ldap.LDAPException;
import netscape.ldap.LDAPMessage;
import netscape.ldap.LDAPResponse;
import netscape.ldap.LDAPSearchListener;
import netscape.ldap.LDAPSearchResult;

/**
 * Asynchrone Suche mit dem Netscape SDK -- (Listing 3_2).
 * 
 * Die Verbindungsdaten sind hart in den Quelltext kodiert, es wird eine anonyme
 * Verbindung aufgebaut. Zur Kompilation und zum Ablauf wird das SDK benoetigt
 * (ldapjdk.jar), vgl. Kapitel 3.1.
 * 
 * @author Stefan Z&ouml;rner
 */
public class SdkAsynchronBeispiel {

  public static void main(String[] args) throws LDAPException,
      InterruptedException {

    LDAPConnection con = new LDAPConnection();
    con.connect("magritte", 389);

    LDAPSearchListener listener = con.search(
        "dc=bundestag,dc=de", LDAPConnection.SCOPE_SUB,
        "(&(objectclass=person)(sn~=Schmidt)(!(mail=*)))",
        new String[] { "cn", "title" }, false,
        (LDAPSearchListener) null);

    do {
      if (listener.isResponseReceived()) {
        LDAPMessage msg = listener.getResponse();
        if (msg instanceof LDAPSearchResult) {
          LDAPSearchResult rs = (LDAPSearchResult) msg;
          System.out.println(rs.getEntry().getDN());
        } else if (msg instanceof LDAPResponse) {
          System.out.println(msg);
        } // else if
      } else {
        Thread.sleep(100);
        System.out.println("#msgs=" + listener.getMessageCount());
      } // else
    } while (listener.getRequestCount() > 0);

    con.disconnect();
  }
}
