/* Beispiele aus dem Buch "LDAP fuer Java-Entwickler", 
 * Stefan Zoerner, 4. aktualisierte Auflage 2013
 *  
 * Webseite zum Buch: http://www.ldapjava.de/ 
 * Software & Support Media GmbH / entwickler.press, http://www.entwickler-press.de/
 */
package ldapbuch.kapitel3.explizit;

import java.util.List;

import com.unboundid.ldap.sdk.CompareResult;
import com.unboundid.ldap.sdk.LDAPConnection;
import com.unboundid.ldap.sdk.LDAPException;
import com.unboundid.ldap.sdk.SearchResult;
import com.unboundid.ldap.sdk.SearchResultEntry;
import com.unboundid.ldap.sdk.SearchScope;

/**
 * Compare- und Suchabfrage mit dem UnboundID LDAP SDK -- (Listing 3_4).
 * 
 * Die Verbindungsdaten sind hart in den Quelltext kodiert, es wird eine anonyme
 * Verbindung aufgebaut. Zur Kompilation und zum Ablauf wird das SDK
 * ben&ouml;tigt (unboundid-ldapsdk-se.jar), vgl. Kapitel 3.1.
 * 
 * @author Stefan Z&ouml;rner
 */
public class UnboundIDBeispiel {

	public static void main(String[] args) throws LDAPException {

		LDAPConnection con = new LDAPConnection("magritte", 389);

		CompareResult compareResult = con.compare(
		    "uid=amerkel,ou=personen,dc=bundestag,dc=de", "givenName", "Angela");
		System.out.println(compareResult.getResultCode());
		System.out.println();

		SearchResult searchResult = con.search("dc=bundestag,dc=de",
		    SearchScope.SUB, "(&(objectclass=person)(sn~=Schmidt)(!(mail=*)))",
		    "cn", "title");

		List<SearchResultEntry> entries = searchResult.getSearchEntries();
		for (SearchResultEntry entry : entries) {
			System.out.println(entry.getDN());
			System.out.println(entry.getAttributeValue("cn"));
			if (entry.hasAttribute("title")) {
				System.out.println(entry.getAttributeValue("title"));
			}
			System.out.println();
		}
		con.close();
	}
}
